==> bootstrap-notify-3.1.36.tgz: bootstrap-notify/README.md <==
# Installation
> `npm install --save @types/bootstrap-notify`

# Summary
This package contains type definitions for bootstrap-notify (http://bootstrap-notify.remabledesigns.com/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-notify.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-notify/index.d.ts)
````ts
// Type definitions for bootstrap-notify v3.1.3
// Project: http://bootstrap-notify.remabledesigns.com/
// Definitions by: Blake Niemyjski <https://github.com/niemyjski>, Robert McIntosh <https://github.com/mouse0270>, Robert Voica <https://github.com/robert-voica>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

interface JQueryStatic {
    notify(message: string): NotifyReturn;
    notify(opts: NotifyOptions, settings?: NotifySettings): NotifyReturn;
    notifyDefaults(settings: NotifySettings): void;
    notifyClose(): void;
    notifyClose(command: string): void;
}

interface NotifyOptions {
    message: string;
    title?: string | undefined;
    icon?: string | undefined;
    url?: string | undefined;
    target?: string | undefined;
}

interface NotifySettings {
    element?: string | undefined;
    position?: string | undefined;
    type?: string | undefined;
    allow_dismiss?: boolean | undefined;
    allow_duplicates?: boolean | undefined;
    newest_on_top?: boolean | undefined;
    showProgressbar?: boolean | undefined;
    placement?: {
        from?: string | undefined;
        align?: string | undefined;
    } | undefined;
    offset?: number | {
        x?: number | undefined;
        y?: number | undefined;
    } | undefined;
    spacing?: number | undefined;
    z_index?: number | undefined;
    delay?: number | undefined;
    timer?: number | undefined;
    url_target?: string | undefined;
    mouse_over?: string | undefined;
    animate?: {
        enter?: string | undefined;
        exit?: string | undefined;
    } | undefined;
    onShow?: (($ele: JQuery) => void) | undefined;
    onShown?: (($ele: JQuery) => void) | undefined;
    onClose?: (($ele: JQuery) => void) | undefined;
    onClosed?: (($ele: JQuery) => void) | undefined;
    icon_type?: string | undefined;
    template?: string | undefined;
}

interface NotifyReturn {
    $ele: JQuery;
    close: () => void;
    update: (command: string, update: any) => void;
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 00:35:33 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Blake Niemyjski](https://github.com/niemyjski), [Robert McIntosh](https://github.com/mouse0270), and [Robert Voica](https://github.com/robert-voica).

==> bootstrap-notify-3.1.37.tgz: bootstrap-notify/README.md <==
# Installation
> `npm install --save @types/bootstrap-notify`

# Summary
This package contains type definitions for bootstrap-notify (http://bootstrap-notify.remabledesigns.com/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-notify.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/bootstrap-notify/index.d.ts)
````ts
/// <reference types="jquery" />

interface JQueryStatic {
    notify(message: string): NotifyReturn;
    notify(opts: NotifyOptions, settings?: NotifySettings): NotifyReturn;
    notifyDefaults(settings: NotifySettings): void;
    notifyClose(): void;
    notifyClose(command: string): void;
}

interface NotifyOptions {
    message: string;
    title?: string | undefined;
    icon?: string | undefined;
    url?: string | undefined;
    target?: string | undefined;
}

interface NotifySettings {
    element?: string | undefined;
    position?: string | undefined;
    type?: string | undefined;
    allow_dismiss?: boolean | undefined;
    allow_duplicates?: boolean | undefined;
    newest_on_top?: boolean | undefined;
    showProgressbar?: boolean | undefined;
    placement?: {
        from?: string | undefined;
        align?: string | undefined;
    } | undefined;
    offset?: number | {
        x?: number | undefined;
        y?: number | undefined;
    } | undefined;
    spacing?: number | undefined;
    z_index?: number | undefined;
    delay?: number | undefined;
    timer?: number | undefined;
    url_target?: string | undefined;
    mouse_over?: string | undefined;
    animate?: {
        enter?: string | undefined;
        exit?: string | undefined;
    } | undefined;
    onShow?: (($ele: JQuery) => void) | undefined;
    onShown?: (($ele: JQuery) => void) | undefined;
    onClose?: (($ele: JQuery) => void) | undefined;
    onClosed?: (($ele: JQuery) => void) | undefined;
    icon_type?: string | undefined;
    template?: string | undefined;
}

interface NotifyReturn {
    $ele: JQuery;
    close: () => void;
    update: (command: string, update: any) => void;
}

````

### Additional Details
 * Last updated: Tue, 17 Oct 2023 22:10:13 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)

# Credits
These definitions were written by [Blake Niemyjski](https://github.com/niemyjski), [Robert McIntosh](https://github.com/mouse0270), and [Robert Voica](https://github.com/robert-voica).
